@@ -6,7 +6,7 @@ use crate::err::{PyDowncastError, PyErr, PyResult};
 use crate::exceptions::PyTypeError;
 use crate::type_object::PyTypeObject;
 use crate::types::{PyDict, PyIterator, PyList, PyString, PyTuple, PyType};
-use crate::{err, ffi, Py, PyNativeType, PyObject};
+use crate::{err, ffi, Py, PyNativeType, PyObject, Python};
 use std::cell::UnsafeCell;
 use std::cmp::Ordering;
 use std::os::raw::c_int;
@@ -219,25 +219,21 @@ impl PyAny {
     /// Depending on the value of `compare_op`, this is equivalent to one of the
     /// following Python expressions:
     ///
-    /// <div style="width:1px">
-    ///
-    /// | `compare_op` | <span style="white-space: pre">Python expression</span> |
+    /// | `compare_op` | Python expression |
     /// | :---: | :----: |
-    /// | [`CompareOp::Eq`] | <span style="white-space: pre">`self == other`</span> |
-    /// | [`CompareOp::Ne`] | <span style="white-space: pre">`self != other`</span> |
-    /// | [`CompareOp::Lt`] | <span style="white-space: pre">`self < other`</span> |
-    /// | [`CompareOp::Le`] | <span style="white-space: pre">`self <= other`</span> |
-    /// | [`CompareOp::Gt`] | <span style="white-space: pre">`self > other`</span> |
-    /// | [`CompareOp::Ge`] | <span style="white-space: pre">`self >= other`</span> |
-    ///
-    /// </div>
+    /// | [`CompareOp::Eq`] | `self == other` |
+    /// | [`CompareOp::Ne`] | `self != other` |
+    /// | [`CompareOp::Lt`] | `self < other` |
+    /// | [`CompareOp::Le`] | `self <= other` |
+    /// | [`CompareOp::Gt`] | `self > other` |
+    /// | [`CompareOp::Ge`] | `self >= other` |
     ///
     /// # Examples
     ///
     /// ```rust
+    /// use pyo3::class::basic::CompareOp;
     /// use pyo3::prelude::*;
     /// use pyo3::types::PyInt;
-    /// use pyo3::class::basic::CompareOp;
     ///
     /// # fn main() -> PyResult<()> {
     /// Python::with_gil(|py| -> PyResult<()> {
@@ -245,7 +241,7 @@ impl PyAny {
     ///     let b: &PyInt = 42_u8.into_py(py).into_ref(py).downcast()?;
     ///     assert!(a.rich_compare(b, CompareOp::Le)?.is_true()?);
     ///     Ok(())
-    ///   })?;
+    /// })?;
     /// # Ok(())}
     /// ```
     pub fn rich_compare<O>(&self, other: O, compare_op: CompareOp) -> PyResult<&PyAny>
@@ -274,10 +270,10 @@ impl PyAny {
     ///
     /// # fn main() -> PyResult<()> {
     /// Python::with_gil(|py| -> PyResult<()> {
-    ///        let builtins = PyModule::import(py, "builtins")?;
-    ///        let print = builtins.getattr("print")?;
-    ///        assert!(print.is_callable());
-    ///        Ok(())
+    ///     let builtins = PyModule::import(py, "builtins")?;
+    ///     let print = builtins.getattr("print")?;
+    ///     assert!(print.is_callable());
+    ///     Ok(())
     /// })?;
     /// # Ok(())}
     /// ```
@@ -363,7 +359,7 @@ impl PyAny {
     /// Python::with_gil(|py| -> PyResult<()> {
     ///     let module = PyModule::import(py, "operator")?;
     ///     let add = module.getattr("add")?;
-    ///     let args = (1,2);
+    ///     let args = (1, 2);
     ///     let value = add.call1(args)?;
     ///     assert_eq!(value.extract::<i32>()?, 3);
     ///     Ok(())
@@ -391,8 +387,7 @@ impl PyAny {
     ///
     /// ```rust
     /// use pyo3::prelude::*;
-    /// use pyo3::types::{PyDict, PyList};
-    /// use crate::pyo3::types::IntoPyDict;
+    /// use pyo3::types::{IntoPyDict, PyList};
     ///
     /// # fn main() -> PyResult<()> {
     /// Python::with_gil(|py| -> PyResult<()> {
@@ -516,11 +511,8 @@ impl PyAny {
     /// This is equivalent to the Python expression `bool(self)`.
     pub fn is_true(&self) -> PyResult<bool> {
         let v = unsafe { ffi::PyObject_IsTrue(self.as_ptr()) };
-        if v == -1 {
-            Err(PyErr::fetch(self.py()))
-        } else {
-            Ok(v != 0)
-        }
+        err::error_on_minusone(self.py(), v)?;
+        Ok(v != 0)
     }
 
     /// Returns whether the object is considered to be None.
@@ -679,6 +671,12 @@ impl PyAny {
     pub fn is_instance<T: PyTypeObject>(&self) -> PyResult<bool> {
         T::type_object(self.py()).is_instance(self)
     }
+
+    /// Returns a GIL marker constrained to the lifetime of this type.
+    #[inline]
+    pub fn py(&self) -> Python<'_> {
+        PyNativeType::py(self)
+    }
 }
 
 #[cfg(test)]
@@ -697,23 +695,23 @@ mod tests {
 
     #[test]
     fn test_call_for_non_existing_method() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let a = py.eval("42", None, None).unwrap();
-        a.call_method0("__str__").unwrap(); // ok
-        assert!(a.call_method("nonexistent_method", (1,), None).is_err());
-        assert!(a.call_method0("nonexistent_method").is_err());
-        assert!(a.call_method1("nonexistent_method", (1,)).is_err());
+        Python::with_gil(|py| {
+            let a = py.eval("42", None, None).unwrap();
+            a.call_method0("__str__").unwrap(); // ok
+            assert!(a.call_method("nonexistent_method", (1,), None).is_err());
+            assert!(a.call_method0("nonexistent_method").is_err());
+            assert!(a.call_method1("nonexistent_method", (1,)).is_err());
+        });
     }
 
     #[test]
     fn test_call_with_kwargs() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let list = vec![3, 6, 5, 4, 7].to_object(py);
-        let dict = vec![("reverse", true)].into_py_dict(py);
-        list.call_method(py, "sort", (), Some(dict)).unwrap();
-        assert_eq!(list.extract::<Vec<i32>>(py).unwrap(), vec![7, 6, 5, 4, 3]);
+        Python::with_gil(|py| {
+            let list = vec![3, 6, 5, 4, 7].to_object(py);
+            let dict = vec![("reverse", true)].into_py_dict(py);
+            list.call_method(py, "sort", (), Some(dict)).unwrap();
+            assert_eq!(list.extract::<Vec<i32>>(py).unwrap(), vec![7, 6, 5, 4, 3]);
+        });
     }
 
     #[test]
@@ -742,47 +740,46 @@ mod tests {
 
     #[test]
     fn test_type() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let obj = py.eval("42", None, None).unwrap();
-        assert_eq!(obj.get_type().as_type_ptr(), obj.get_type_ptr())
+        Python::with_gil(|py| {
+            let obj = py.eval("42", None, None).unwrap();
+            assert_eq!(obj.get_type().as_type_ptr(), obj.get_type_ptr());
+        });
     }
 
     #[test]
     fn test_dir() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let obj = py.eval("42", None, None).unwrap();
-        let dir = py
-            .eval("dir(42)", None, None)
-            .unwrap()
-            .downcast::<PyList>()
-            .unwrap();
-        let a = obj
-            .dir()
-            .into_iter()
-            .map(|x| x.extract::<String>().unwrap());
-        let b = dir.into_iter().map(|x| x.extract::<String>().unwrap());
-        assert!(a.eq(b));
+        Python::with_gil(|py| {
+            let obj = py.eval("42", None, None).unwrap();
+            let dir = py
+                .eval("dir(42)", None, None)
+                .unwrap()
+                .downcast::<PyList>()
+                .unwrap();
+            let a = obj
+                .dir()
+                .into_iter()
+                .map(|x| x.extract::<String>().unwrap());
+            let b = dir.into_iter().map(|x| x.extract::<String>().unwrap());
+            assert!(a.eq(b));
+        });
     }
 
     #[test]
     fn test_nan_eq() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-        let nan = py.eval("float('nan')", None, None).unwrap();
-        assert!(nan.compare(nan).is_err());
+        Python::with_gil(|py| {
+            let nan = py.eval("float('nan')", None, None).unwrap();
+            assert!(nan.compare(nan).is_err());
+        });
     }
 
     #[test]
     fn test_any_isinstance() {
-        let gil = Python::acquire_gil();
-        let py = gil.python();
+        Python::with_gil(|py| {
+            let x = 5.to_object(py).into_ref(py);
+            assert!(x.is_instance::<PyLong>().unwrap());
 
-        let x = 5.to_object(py).into_ref(py);
-        assert!(x.is_instance::<PyLong>().unwrap());
-
-        let l = vec![x, x].to_object(py).into_ref(py);
-        assert!(l.is_instance::<PyList>().unwrap());
+            let l = vec![x, x].to_object(py).into_ref(py);
+            assert!(l.is_instance::<PyList>().unwrap());
+        });
     }
 }
